Documentation
¶
Overview ¶
Package unet include resources of ucloud unet product
See also
- API: https://docs.ucloud.cn/api/unet-api/index
- Product: https://www.ucloud.cn/site/product/unet.html
for detail.
Index ¶
- type AllocateEIPRequest
- type AllocateEIPResponse
- type AllocateShareBandwidthRequest
- type AllocateShareBandwidthResponse
- type AllocateVIPRequest
- type AllocateVIPResponse
- type AssociateEIPWithShareBandwidthRequest
- type AssociateEIPWithShareBandwidthResponse
- type BindEIPRequest
- type BindEIPResponse
- type CreateBandwidthPackageRequest
- type CreateBandwidthPackageResponse
- type CreateFirewallRequest
- type CreateFirewallResponse
- type DeleteBandwidthPackageRequest
- type DeleteBandwidthPackageResponse
- type DeleteFirewallRequest
- type DeleteFirewallResponse
- type DescribeBandwidthPackageRequest
- type DescribeBandwidthPackageResponse
- type DescribeBandwidthUsageRequest
- type DescribeBandwidthUsageResponse
- type DescribeEIPRequest
- type DescribeEIPResponse
- type DescribeFirewallRequest
- type DescribeFirewallResourceRequest
- type DescribeFirewallResourceResponse
- type DescribeFirewallResponse
- type DescribeShareBandwidthRequest
- type DescribeShareBandwidthResponse
- type DescribeVIPRequest
- type DescribeVIPResponse
- type DisassociateEIPWithShareBandwidthRequest
- type DisassociateEIPWithShareBandwidthResponse
- type EIPAddrSet
- type EIPPayModeSet
- type EIPPriceDetailSet
- type EIPSetData
- type FirewallDataSet
- type FirewallRuleSet
- type GetEIPPayModeRequest
- type GetEIPPayModeResponse
- type GetEIPPriceRequest
- type GetEIPPriceResponse
- type GetEIPUpgradePriceRequest
- type GetEIPUpgradePriceResponse
- type GrantFirewallRequest
- type GrantFirewallResponse
- type ModifyEIPBandwidthRequest
- type ModifyEIPBandwidthResponse
- type ModifyEIPWeightRequest
- type ModifyEIPWeightResponse
- type ReleaseEIPRequest
- type ReleaseEIPResponse
- type ReleaseShareBandwidthRequest
- type ReleaseShareBandwidthResponse
- type ReleaseVIPRequest
- type ReleaseVIPResponse
- type ResizeShareBandwidthRequest
- type ResizeShareBandwidthResponse
- type ResourceSet
- type SetEIPPayModeRequest
- type SetEIPPayModeResponse
- type ShareBandwidthSet
- type UNetClient
- func (c *UNetClient) AllocateEIP(req *AllocateEIPRequest) (*AllocateEIPResponse, error)
- func (c *UNetClient) AllocateShareBandwidth(req *AllocateShareBandwidthRequest) (*AllocateShareBandwidthResponse, error)
- func (c *UNetClient) AllocateVIP(req *AllocateVIPRequest) (*AllocateVIPResponse, error)
- func (c *UNetClient) AssociateEIPWithShareBandwidth(req *AssociateEIPWithShareBandwidthRequest) (*AssociateEIPWithShareBandwidthResponse, error)
- func (c *UNetClient) BindEIP(req *BindEIPRequest) (*BindEIPResponse, error)
- func (c *UNetClient) CreateBandwidthPackage(req *CreateBandwidthPackageRequest) (*CreateBandwidthPackageResponse, error)
- func (c *UNetClient) CreateFirewall(req *CreateFirewallRequest) (*CreateFirewallResponse, error)
- func (c *UNetClient) DeleteBandwidthPackage(req *DeleteBandwidthPackageRequest) (*DeleteBandwidthPackageResponse, error)
- func (c *UNetClient) DeleteFirewall(req *DeleteFirewallRequest) (*DeleteFirewallResponse, error)
- func (c *UNetClient) DescribeBandwidthPackage(req *DescribeBandwidthPackageRequest) (*DescribeBandwidthPackageResponse, error)
- func (c *UNetClient) DescribeBandwidthUsage(req *DescribeBandwidthUsageRequest) (*DescribeBandwidthUsageResponse, error)
- func (c *UNetClient) DescribeEIP(req *DescribeEIPRequest) (*DescribeEIPResponse, error)
- func (c *UNetClient) DescribeFirewall(req *DescribeFirewallRequest) (*DescribeFirewallResponse, error)
- func (c *UNetClient) DescribeFirewallResource(req *DescribeFirewallResourceRequest) (*DescribeFirewallResourceResponse, error)
- func (c *UNetClient) DescribeShareBandwidth(req *DescribeShareBandwidthRequest) (*DescribeShareBandwidthResponse, error)
- func (c *UNetClient) DescribeVIP(req *DescribeVIPRequest) (*DescribeVIPResponse, error)
- func (c *UNetClient) DisassociateEIPWithShareBandwidth(req *DisassociateEIPWithShareBandwidthRequest) (*DisassociateEIPWithShareBandwidthResponse, error)
- func (c *UNetClient) GetEIPPayMode(req *GetEIPPayModeRequest) (*GetEIPPayModeResponse, error)
- func (c *UNetClient) GetEIPPrice(req *GetEIPPriceRequest) (*GetEIPPriceResponse, error)
- func (c *UNetClient) GetEIPUpgradePrice(req *GetEIPUpgradePriceRequest) (*GetEIPUpgradePriceResponse, error)
- func (c *UNetClient) GrantFirewall(req *GrantFirewallRequest) (*GrantFirewallResponse, error)
- func (c *UNetClient) ModifyEIPBandwidth(req *ModifyEIPBandwidthRequest) (*ModifyEIPBandwidthResponse, error)
- func (c *UNetClient) ModifyEIPWeight(req *ModifyEIPWeightRequest) (*ModifyEIPWeightResponse, error)
- func (c *UNetClient) NewAllocateEIPRequest() *AllocateEIPRequest
- func (c *UNetClient) NewAllocateShareBandwidthRequest() *AllocateShareBandwidthRequest
- func (c *UNetClient) NewAllocateVIPRequest() *AllocateVIPRequest
- func (c *UNetClient) NewAssociateEIPWithShareBandwidthRequest() *AssociateEIPWithShareBandwidthRequest
- func (c *UNetClient) NewBindEIPRequest() *BindEIPRequest
- func (c *UNetClient) NewCreateBandwidthPackageRequest() *CreateBandwidthPackageRequest
- func (c *UNetClient) NewCreateFirewallRequest() *CreateFirewallRequest
- func (c *UNetClient) NewDeleteBandwidthPackageRequest() *DeleteBandwidthPackageRequest
- func (c *UNetClient) NewDeleteFirewallRequest() *DeleteFirewallRequest
- func (c *UNetClient) NewDescribeBandwidthPackageRequest() *DescribeBandwidthPackageRequest
- func (c *UNetClient) NewDescribeBandwidthUsageRequest() *DescribeBandwidthUsageRequest
- func (c *UNetClient) NewDescribeEIPRequest() *DescribeEIPRequest
- func (c *UNetClient) NewDescribeFirewallRequest() *DescribeFirewallRequest
- func (c *UNetClient) NewDescribeFirewallResourceRequest() *DescribeFirewallResourceRequest
- func (c *UNetClient) NewDescribeShareBandwidthRequest() *DescribeShareBandwidthRequest
- func (c *UNetClient) NewDescribeVIPRequest() *DescribeVIPRequest
- func (c *UNetClient) NewDisassociateEIPWithShareBandwidthRequest() *DisassociateEIPWithShareBandwidthRequest
- func (c *UNetClient) NewGetEIPPayModeRequest() *GetEIPPayModeRequest
- func (c *UNetClient) NewGetEIPPriceRequest() *GetEIPPriceRequest
- func (c *UNetClient) NewGetEIPUpgradePriceRequest() *GetEIPUpgradePriceRequest
- func (c *UNetClient) NewGrantFirewallRequest() *GrantFirewallRequest
- func (c *UNetClient) NewModifyEIPBandwidthRequest() *ModifyEIPBandwidthRequest
- func (c *UNetClient) NewModifyEIPWeightRequest() *ModifyEIPWeightRequest
- func (c *UNetClient) NewReleaseEIPRequest() *ReleaseEIPRequest
- func (c *UNetClient) NewReleaseShareBandwidthRequest() *ReleaseShareBandwidthRequest
- func (c *UNetClient) NewReleaseVIPRequest() *ReleaseVIPRequest
- func (c *UNetClient) NewResizeShareBandwidthRequest() *ResizeShareBandwidthRequest
- func (c *UNetClient) NewSetEIPPayModeRequest() *SetEIPPayModeRequest
- func (c *UNetClient) NewUnBindEIPRequest() *UnBindEIPRequest
- func (c *UNetClient) NewUpdateEIPAttributeRequest() *UpdateEIPAttributeRequest
- func (c *UNetClient) NewUpdateFirewallAttributeRequest() *UpdateFirewallAttributeRequest
- func (c *UNetClient) NewUpdateFirewallRequest() *UpdateFirewallRequest
- func (c *UNetClient) NewUpdateVIPAttributeRequest() *UpdateVIPAttributeRequest
- func (c *UNetClient) ReleaseEIP(req *ReleaseEIPRequest) (*ReleaseEIPResponse, error)
- func (c *UNetClient) ReleaseShareBandwidth(req *ReleaseShareBandwidthRequest) (*ReleaseShareBandwidthResponse, error)
- func (c *UNetClient) ReleaseVIP(req *ReleaseVIPRequest) (*ReleaseVIPResponse, error)
- func (c *UNetClient) ResizeShareBandwidth(req *ResizeShareBandwidthRequest) (*ResizeShareBandwidthResponse, error)
- func (c *UNetClient) SetEIPPayMode(req *SetEIPPayModeRequest) (*SetEIPPayModeResponse, error)
- func (c *UNetClient) UnBindEIP(req *UnBindEIPRequest) (*UnBindEIPResponse, error)
- func (c *UNetClient) UpdateEIPAttribute(req *UpdateEIPAttributeRequest) (*UpdateEIPAttributeResponse, error)
- func (c *UNetClient) UpdateFirewall(req *UpdateFirewallRequest) (*UpdateFirewallResponse, error)
- func (c *UNetClient) UpdateFirewallAttribute(req *UpdateFirewallAttributeRequest) (*UpdateFirewallAttributeResponse, error)
- func (c *UNetClient) UpdateVIPAttribute(req *UpdateVIPAttributeRequest) (*UpdateVIPAttributeResponse, error)
- type UnBindEIPRequest
- type UnBindEIPResponse
- type UnetAllocateEIPSet
- type UnetBandwidthPackageSet
- type UnetBandwidthUsageEIPSet
- type UnetEIPAddrSet
- type UnetEIPResourceSet
- type UnetEIPSet
- type UnetShareBandwidthSet
- type UpdateEIPAttributeRequest
- type UpdateEIPAttributeResponse
- type UpdateFirewallAttributeRequest
- type UpdateFirewallAttributeResponse
- type UpdateFirewallRequest
- type UpdateFirewallResponse
- type UpdateVIPAttributeRequest
- type UpdateVIPAttributeResponse
- type VIPDetailSet
- type VIPSet
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AllocateEIPRequest ¶
type AllocateEIPRequest struct {
request.CommonBase
// 弹性IP的线路如下: 国际: International BGP: Bgp 各地域允许的线路参数如下: cn-sh1: Bgp cn-sh2: Bgp cn-gd: Bgp cn-bj1: Bgp cn-bj2: Bgp hk: International us-ca: International th-bkk: International kr-seoul:International us-ws:International ge-fra:International sg:International tw-kh:International.其他海外线路均为 International
OperatorName *string `required:"true"`
// 弹性IP的外网带宽, 单位为Mbps. 共享带宽模式必须指定0M带宽, 非共享带宽模式必须指定非0Mbps带宽. 各地域非共享带宽的带宽范围如下: 流量计费[1-200],带宽计费[1-800]
Bandwidth *int `required:"true"`
// 业务组名称, 默认为 "Default"
Tag *string `required:"false"`
// 付费方式, 枚举值为: Year, 按年付费; Month, 按月付费; Dynamic, 按需付费(需开启权限); Trial, 试用(需开启权限) 默认为按月付费
ChargeType *string `required:"false"`
// 购买时长, 默认: 1
Quantity *int `required:"false"`
// 弹性IP的计费模式. 枚举值: "Traffic", 流量计费; "Bandwidth", 带宽计费; "ShareBandwidth",共享带宽模式. 默认为 "Bandwidth".
PayMode *string `required:"false"`
ShareBandwidthId *string `required:"false"`
// 弹性IP的名称, 默认为 "EIP"
Name *string `required:"false"`
// 弹性IP的备注, 默认为空
Remark *string `required:"false"`
// 代金券ID, 默认不使用
CouponId *string `required:"false"`
}
AllocateEIPRequest is request schema for AllocateEIP action
type AllocateEIPResponse ¶
type AllocateEIPResponse struct {
response.CommonBase
// 申请到的EIP资源详情 参见 UnetAllocateEIPSet
EIPSet []UnetAllocateEIPSet
}
AllocateEIPResponse is response schema for AllocateEIP action
type AllocateShareBandwidthRequest ¶
type AllocateShareBandwidthRequest struct {
Name *string `required:"true"`
ChargeType *string `required:"true"`
ShareBandwidth *int `required:"true"`
Quantity *int `required:"false"`
ShareBandwidthGuarantee *int `required:"false"`
}
AllocateShareBandwidthRequest is request schema for AllocateShareBandwidth action
type AllocateShareBandwidthResponse ¶
type AllocateShareBandwidthResponse struct {
ShareBandwidthId string
}
AllocateShareBandwidthResponse is response schema for AllocateShareBandwidth action
type AllocateVIPRequest ¶
type AllocateVIPRequest struct {
request.CommonBase
// 指定vip所属的VPC
VPCId *string `required:"true"`
// 子网id
SubnetId *string `required:"true"`
// 申请数量,默认: 1
Count *int `required:"false"`
// vip名,默认为VIP
Name *string `required:"false"`
// 业务组名称,默认为Default
Tag *string `required:"false"`
// 备注
Remark *string `required:"false"`
// 业务组
BusinessId *string `required:"false"`
}
AllocateVIPRequest is request schema for AllocateVIP action
type AllocateVIPResponse ¶
type AllocateVIPResponse struct {
response.CommonBase
// 申请到的VIP资源相关信息
VIPSet []VIPSet
// 申请到的VIP地址
DataSet []string
}
AllocateVIPResponse is response schema for AllocateVIP action
type AssociateEIPWithShareBandwidthRequest ¶
type AssociateEIPWithShareBandwidthRequest struct {
EIPIds []string `required:"true"`
ShareBandwidthId *string `required:"true"`
}
AssociateEIPWithShareBandwidthRequest is request schema for AssociateEIPWithShareBandwidth action
type AssociateEIPWithShareBandwidthResponse ¶
type AssociateEIPWithShareBandwidthResponse struct {
}
AssociateEIPWithShareBandwidthResponse is response schema for AssociateEIPWithShareBandwidth action
type BindEIPRequest ¶
type BindEIPRequest struct {
request.CommonBase
// 弹性IP的资源Id
EIPId *string `required:"true"`
// 弹性IP请求绑定的资源类型, 枚举值为: uhost: 云主机; ulb, 负载均衡器 upm: 物理机; hadoophost: 大数据集群;fortresshost:堡垒机;udockhost:容器;udhost:私有专区主机;natgw:natgw;udb:udb;vpngw:ipsec vpn;ucdr:云灾备;dbaudit:数据库审计;
ResourceType *string `required:"true"`
// 弹性IP请求绑定的资源ID
ResourceId *string `required:"true"`
}
BindEIPRequest is request schema for BindEIP action
type BindEIPResponse ¶
type BindEIPResponse struct {
response.CommonBase
}
BindEIPResponse is response schema for BindEIP action
type CreateBandwidthPackageRequest ¶
type CreateBandwidthPackageRequest struct {
request.CommonBase
// 带宽大小(单位Mbps), 取值范围[2,800] (最大值受地域限制)
Bandwidth *int `required:"true"`
// 所绑定弹性IP的资源ID
EIPId *string `required:"true"`
// 带宽包有效时长, 取值范围为大于0的整数, 即该带宽包在EnableTime到 EnableTime+TimeRange时间段内生效
TimeRange *int `required:"true"`
// 生效时间, 格式为 Unix timestamp, 默认为立即开通
EnableTime *int `required:"false"`
// 代金券ID
CouponId *string `required:"false"`
}
CreateBandwidthPackageRequest is request schema for CreateBandwidthPackage action
type CreateBandwidthPackageResponse ¶
type CreateBandwidthPackageResponse struct {
response.CommonBase
// 所创建带宽包的资源ID
BandwidthPackageId string
}
CreateBandwidthPackageResponse is response schema for CreateBandwidthPackage action
type CreateFirewallRequest ¶
type CreateFirewallRequest struct {
request.CommonBase
// 防火墙规则,例如:TCP|22|192.168.1.1/22|DROP|LOW|禁用22端口,第一个参数代表协议:第二个参数代表端口号,第三个参数为ip,第四个参数为ACCEPT(接受)和DROP(拒绝),第五个参数优先级:HIGH(高),MEDIUM(中),LOW(低),第六个参数为该条规则的自定义备注
Rule []string `required:"true"`
// 防火墙名称
Name *string `required:"true"`
// 防火墙业务组,默认为Default
Tag *string `required:"false"`
// 防火墙描述,默认为空
Remark *string `required:"false"`
}
CreateFirewallRequest is request schema for CreateFirewall action
type CreateFirewallResponse ¶
type CreateFirewallResponse struct {
response.CommonBase
// 防火墙ID
FWId string
}
CreateFirewallResponse is response schema for CreateFirewall action
type DeleteBandwidthPackageRequest ¶
type DeleteBandwidthPackageRequest struct {
request.CommonBase
// 带宽包资源ID
BandwidthPackageId *string `required:"true"`
}
DeleteBandwidthPackageRequest is request schema for DeleteBandwidthPackage action
type DeleteBandwidthPackageResponse ¶
type DeleteBandwidthPackageResponse struct {
response.CommonBase
}
DeleteBandwidthPackageResponse is response schema for DeleteBandwidthPackage action
type DeleteFirewallRequest ¶
type DeleteFirewallRequest struct {
request.CommonBase
// 防火墙资源ID
FWId *string `required:"true"`
}
DeleteFirewallRequest is request schema for DeleteFirewall action
type DeleteFirewallResponse ¶
type DeleteFirewallResponse struct {
response.CommonBase
}
DeleteFirewallResponse is response schema for DeleteFirewall action
type DescribeBandwidthPackageRequest ¶
type DescribeBandwidthPackageRequest struct {
request.CommonBase
// 返回数据分页值, 取值范围为 [0,10000000] 之间的整数, 默认为20
Limit *int `required:"false"`
// 返回数据偏移量, 默认为0
Offset *int `required:"false"`
}
DescribeBandwidthPackageRequest is request schema for DescribeBandwidthPackage action
type DescribeBandwidthPackageResponse ¶
type DescribeBandwidthPackageResponse struct {
response.CommonBase
// 满足条件的带宽包总数
TotalCount int
// 带宽包详细信息, 参见 UnetBandwidthPackageSet
DataSets []UnetBandwidthPackageSet
}
DescribeBandwidthPackageResponse is response schema for DescribeBandwidthPackage action
type DescribeBandwidthUsageRequest ¶
type DescribeBandwidthUsageRequest struct {
request.CommonBase
// 返回数据分页值, 取值范围为 [0,10000000] 之间的整数, 默认为20
Limit *int `required:"false"`
// 返回数据偏移量, 默认为0
OffSet *int `required:"false"`
// 弹性IP的资源Id. 如果为空, 则返回当前 Region中符合条件的所有EIP的带宽用量, n为自然数
EIPIds []string `required:"false"`
}
DescribeBandwidthUsageRequest is request schema for DescribeBandwidthUsage action
type DescribeBandwidthUsageResponse ¶
type DescribeBandwidthUsageResponse struct {
response.CommonBase
// EIPSet中的元素个数
TotalCount int
// 单个弹性IP的带宽用量详细信息, 详见 UnetBandwidthUsageEIPSet, 如没有弹性IP资源则没有该返回值。
EIPSet []UnetBandwidthUsageEIPSet
}
DescribeBandwidthUsageResponse is response schema for DescribeBandwidthUsage action
type DescribeEIPRequest ¶
type DescribeEIPRequest struct {
request.CommonBase
// 弹性IP的资源ID如果为空, 则返回当前 Region中符合条件的的所有EIP
EIPIds []string `required:"false"`
// 数据偏移量, 默认为0
Offset *int `required:"false"`
// 数据分页值, 默认为20
Limit *int `required:"false"`
}
DescribeEIPRequest is request schema for DescribeEIP action
type DescribeEIPResponse ¶
type DescribeEIPResponse struct {
response.CommonBase
// 满足条件的弹性IP总数
TotalCount int
// 满足条件的弹性IP带宽总和, 单位Mbps
TotalBandwidth int
// 弹性IP列表, 每项参数详见 UnetEIPSet
EIPSet []UnetEIPSet
}
DescribeEIPResponse is response schema for DescribeEIP action
type DescribeFirewallRequest ¶
type DescribeFirewallRequest struct {
request.CommonBase
// 防火墙ID,默认为返回所有防火墙
FWId *string `required:"false"`
// 绑定防火墙组的资源类型,默认为全部资源类型。枚举值为:"unatgw",NAT网关; "uhost",云主机; "upm",物理云主机; "hadoophost",hadoop节点; "fortresshost",堡垒机; "udhost",私有专区主机;"udockhost",容器;"dbaudit",数据库审计.
ResourceType *string `required:"false"`
// 绑定防火墙组的资源ID
ResourceId *string `required:"false"`
// 返回数据长度,默认为20,最大10000000
Limit *int `required:"false"`
// 列表起始位置偏移量,默认为0
Offset *int `required:"false"`
}
DescribeFirewallRequest is request schema for DescribeFirewall action
type DescribeFirewallResourceRequest ¶
type DescribeFirewallResourceRequest struct {
request.CommonBase
// 防火墙ID
FWId *string `required:"true"`
// 返回数据长度,默认为20,最大10000000
Limit *string `required:"false"`
// 列表起始位置偏移量,默认为0
Offset *string `required:"false"`
}
DescribeFirewallResourceRequest is request schema for DescribeFirewallResource action
type DescribeFirewallResourceResponse ¶
type DescribeFirewallResourceResponse struct {
response.CommonBase
// 资源列表,见 ResourceSet
ResourceSet []ResourceSet
// 绑定资源总数
TotalCount int
}
DescribeFirewallResourceResponse is response schema for DescribeFirewallResource action
type DescribeFirewallResponse ¶
type DescribeFirewallResponse struct {
response.CommonBase
// 获取的防火墙组详细信息 参见 FirewallDataSet
DataSet []FirewallDataSet
// 数量
TotalCount int
}
DescribeFirewallResponse is response schema for DescribeFirewall action
type DescribeShareBandwidthRequest ¶
type DescribeShareBandwidthRequest struct {
ShareBandwidthIds []string `required:"false"`
}
DescribeShareBandwidthRequest is request schema for DescribeShareBandwidth action
type DescribeShareBandwidthResponse ¶
type DescribeShareBandwidthResponse struct {
DataSet []UnetShareBandwidthSet
TotalCount int
}
DescribeShareBandwidthResponse is response schema for DescribeShareBandwidth action
type DescribeVIPRequest ¶
type DescribeVIPRequest struct {
request.CommonBase
// 业务组
BusinessId *string `required:"false"`
// 子网id,不指定则获取VPCId下的所有vip
SubnetId *string `required:"false"`
// 业务组名称, 默认为 Default
Tag *string `required:"false"`
// VIP ID
VIPId *string `required:"false"`
// vpc的id,指定SubnetId时必填
VPCId *string `required:"false"`
}
DescribeVIPRequest is request schema for DescribeVIP action
type DescribeVIPResponse ¶
type DescribeVIPResponse struct {
response.CommonBase
// 内网VIP地址列表
DataSet []string
// vip数量
TotalCount int
// 内网VIP详情,请见VIPDetailSet
VIPSet []VIPDetailSet
}
DescribeVIPResponse is response schema for DescribeVIP action
type DisassociateEIPWithShareBandwidthRequest ¶
type DisassociateEIPWithShareBandwidthRequest struct {
ShareBandwidthId *string `required:"true"`
Bandwidth *int `required:"true"`
EIPIds []string `required:"false"`
PayMode *string `required:"false"`
}
DisassociateEIPWithShareBandwidthRequest is request schema for DisassociateEIPWithShareBandwidth action
type DisassociateEIPWithShareBandwidthResponse ¶
type DisassociateEIPWithShareBandwidthResponse struct {
}
DisassociateEIPWithShareBandwidthResponse is response schema for DisassociateEIPWithShareBandwidth action
type EIPAddrSet ¶
type EIPAddrSet struct {
// 运营商信息, 枚举值为: BGP: BGP; International: 国际.
OperatorName string
// 弹性IP地址
IP string
}
EIPAddrSet - DescribeBandwidthPackage
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type EIPPayModeSet ¶
type EIPPayModeSet struct {
// EIP的资源ID
EIPId string
// EIP的计费模式. 枚举值为:Bandwidth, 带宽计费;Traffic, 流量计费; "ShareBandwidth",共享带宽模式
EIPPayMode string
}
EIPPayModeSet - GetEIPPayModeEIP
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type EIPPriceDetailSet ¶
type EIPPriceDetailSet struct {
// 弹性IP付费方式
ChargeType string
// 弹性IP价格, 单位"元"
Price float64
// 资源有效期, 以Unix Timestamp表示
PurchaseValue int
}
EIPPriceDetailSet - GetEIPPrice
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type EIPSetData ¶
type EIPSetData struct {
// EIP带宽值
Bandwidth int
// EIP的IP信息,详情见EIPAddrSet
EIPAddr []EIPAddrSet
// EIP资源Id
EIPId string
}
EIPSetData - describeShareBandwidth
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type FirewallDataSet ¶
type FirewallDataSet struct {
// 防火墙ID
FWId string
// 安全组ID(即将废弃)
GroupId string
// 防火墙名称
Name string
// 防火墙业务组
Tag string
// 防火墙备注
Remark string
// 防火墙绑定资源数量
ResourceCount int
// 防火墙组创建时间,格式为Unix Timestamp
CreateTime int
// 防火墙组类型,枚举值为: "user defined", 用户自定义防火墙; "recommend web", 默认Web防火墙; "recommend non web", 默认非Web防火墙
Type string
// 防火墙组中的规则列表,参见 FirewallRuleSet
Rule []FirewallRuleSet
}
FirewallDataSet - DescribeFirewall
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type FirewallRuleSet ¶
type FirewallRuleSet struct {
// 源地址
SrcIP string
// 优先级
Priority string
// 协议类型
ProtocolType string
// 目标端口
DstPort string
// 防火墙动作
RuleAction string
// 防火墙规则备注
Remark string
}
FirewallRuleSet - DescribeFirewall
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type GetEIPPayModeRequest ¶
type GetEIPPayModeRequest struct {
request.CommonBase
// 弹性IP的资源Id
EIPId []string `required:"true"`
}
GetEIPPayModeRequest is request schema for GetEIPPayMode action
type GetEIPPayModeResponse ¶
type GetEIPPayModeResponse struct {
response.CommonBase
// EIP的计费模式, 参见 EIPPayModeSet
EIPPayMode []EIPPayModeSet
}
GetEIPPayModeResponse is response schema for GetEIPPayMode action
type GetEIPPriceRequest ¶
type GetEIPPriceRequest struct {
request.CommonBase
// 弹性IP的线路如下: 国际: International BGP: Bgp 各地域允许的线路参数如下: cn-sh1: Bgp cn-sh2: Bgp cn-gd: Bgp cn-bj1: Bgp cn-bj2: Bgp hk: International us-ca: International th-bkk: International kr-seoul:International us-ws:International ge-fra:International sg:International tw-kh:International.其他海外线路均为 International
OperatorName *string `required:"true"`
// 弹性IP的外网带宽, 单位为Mbps, 范围 [0-800]
Bandwidth *int `required:"true"`
// 付费方式, 枚举值为: Year, 按年付费; Month, 按月付费; Dynamic, 按需付费(需开启权限); 默认为获取三种价格
ChargeType *string `required:"false"`
// 弹性IP计费方式r. 枚举值为: Traffic, 流量计费; Bandwidth, 带宽计费; "ShareBandwidth",共享带宽模式. 默认为Bandwidth
PayMode *string `required:"false"`
}
GetEIPPriceRequest is request schema for GetEIPPrice action
type GetEIPPriceResponse ¶
type GetEIPPriceResponse struct {
response.CommonBase
// 弹性IP价格详情 详情见 EIPPriceDetailSet
PriceSet []EIPPriceDetailSet
}
GetEIPPriceResponse is response schema for GetEIPPrice action
type GetEIPUpgradePriceRequest ¶
type GetEIPUpgradePriceRequest struct {
request.CommonBase
// 弹性IP的资源ID
EIPId *string `required:"true"`
// 弹性IP的外网带宽, 单位为Mbps, 范围 [1-800]
Bandwidth *int `required:"true"`
}
GetEIPUpgradePriceRequest is request schema for GetEIPUpgradePrice action
type GetEIPUpgradePriceResponse ¶
type GetEIPUpgradePriceResponse struct {
response.CommonBase
// 调整带宽后的EIP价格, 单位为"元", 如需退费此处为负值
Price float64
}
GetEIPUpgradePriceResponse is response schema for GetEIPUpgradePrice action
type GrantFirewallRequest ¶
type GrantFirewallRequest struct {
request.CommonBase
// 防火墙资源ID
FWId *string `required:"true"`
// 绑定防火墙组的资源类型,默认为全部资源类型。枚举值为:"unatgw",NAT网关; "uhost",云主机; "upm",物理云主机; "hadoophost",hadoop节点; "fortresshost",堡垒机; "udhost",私有专区主机;"udockhost",容器;"dbaudit",数据库审计.
ResourceType *string `required:"true"`
// 所应用资源ID
ResourceId *string `required:"true"`
}
GrantFirewallRequest is request schema for GrantFirewall action
type GrantFirewallResponse ¶
type GrantFirewallResponse struct {
response.CommonBase
}
GrantFirewallResponse is response schema for GrantFirewall action
type ModifyEIPBandwidthRequest ¶
type ModifyEIPBandwidthRequest struct {
request.CommonBase
// 弹性IP的资源ID
EIPId *string `required:"true"`
// 弹性IP的外网带宽, 单位为Mbps. 各地域的带宽值范围如下:流量计费[1-200],带宽计费[1-800]
Bandwidth *int `required:"true"`
}
ModifyEIPBandwidthRequest is request schema for ModifyEIPBandwidth action
type ModifyEIPBandwidthResponse ¶
type ModifyEIPBandwidthResponse struct {
response.CommonBase
}
ModifyEIPBandwidthResponse is response schema for ModifyEIPBandwidth action
type ModifyEIPWeightRequest ¶
type ModifyEIPWeightRequest struct {
request.CommonBase
// 弹性IP的资源ID
EIPId *string `required:"true"`
// 外网出口权重, 范围[0-100] 取值为0时, 该弹性IP不会被使用. 取值为100时, 同主机下只会使用这个弹性IP,其他弹性IP不会被使用 请勿将多个绑定在同一资源的弹性IP设置为相同权重
Weight *int `required:"true"`
}
ModifyEIPWeightRequest is request schema for ModifyEIPWeight action
type ModifyEIPWeightResponse ¶
type ModifyEIPWeightResponse struct {
response.CommonBase
}
ModifyEIPWeightResponse is response schema for ModifyEIPWeight action
type ReleaseEIPRequest ¶
type ReleaseEIPRequest struct {
request.CommonBase
// 弹性IP的资源ID
EIPId *string `required:"true"`
}
ReleaseEIPRequest is request schema for ReleaseEIP action
type ReleaseEIPResponse ¶
type ReleaseEIPResponse struct {
response.CommonBase
}
ReleaseEIPResponse is response schema for ReleaseEIP action
type ReleaseShareBandwidthRequest ¶
type ReleaseShareBandwidthRequest struct {
ShareBandwidthId *string `required:"true"`
EIPBandwidth *int `required:"true"`
PayMode *string `required:"false"`
}
ReleaseShareBandwidthRequest is request schema for ReleaseShareBandwidth action
type ReleaseShareBandwidthResponse ¶
type ReleaseShareBandwidthResponse struct {
}
ReleaseShareBandwidthResponse is response schema for ReleaseShareBandwidth action
type ReleaseVIPRequest ¶
type ReleaseVIPRequest struct {
request.CommonBase
// 内网VIP的id
VIPId *string `required:"true"`
}
ReleaseVIPRequest is request schema for ReleaseVIP action
type ReleaseVIPResponse ¶
type ReleaseVIPResponse struct {
response.CommonBase
}
ReleaseVIPResponse is response schema for ReleaseVIP action
type ResizeShareBandwidthRequest ¶
type ResizeShareBandwidthRequest struct {
ShareBandwidth *int `required:"true"`
ShareBandwidthId *string `required:"true"`
}
ResizeShareBandwidthRequest is request schema for ResizeShareBandwidth action
type ResizeShareBandwidthResponse ¶
type ResizeShareBandwidthResponse struct {
}
ResizeShareBandwidthResponse is response schema for ResizeShareBandwidth action
type ResourceSet ¶
type ResourceSet struct {
// 可用区
Zone int
// 名称
Name string
// 内网IP
PrivateIP string
// 备注
Remark string
// 绑定该防火墙的资源id
ResourceID string
// 绑定防火墙组的资源类型。"unatgw",NAT网关; "uhost",云主机; "upm",物理云主机; "hadoophost",hadoop节点; "fortresshost",堡垒机; "udhost",私有专区主机;"udockhost",容器;"dbaudit",数据库审计.
ResourceType string
// 状态
Status int
// 业务组
Tag string
}
ResourceSet - 资源信息
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type SetEIPPayModeRequest ¶
type SetEIPPayModeRequest struct {
request.CommonBase
// 弹性IP的资源Id
EIPId *string `required:"true"`
// 计费模式. 枚举值:"Traffic", 流量计费模式; "Bandwidth", 带宽计费模式
PayMode *string `required:"true"`
// 调整的目标带宽值, 单位Mbps. 各地域的带宽值范围如下: 流量计费[1-200],其余情况[1-800]
Bandwidth *int `required:"true"`
}
SetEIPPayModeRequest is request schema for SetEIPPayMode action
type SetEIPPayModeResponse ¶
type SetEIPPayModeResponse struct {
response.CommonBase
}
SetEIPPayModeResponse is response schema for SetEIPPayMode action
type ShareBandwidthSet ¶
type ShareBandwidthSet struct {
ShareBandwidth int
ShareBandwidthName string
ShareBandwidthId string
}
ShareBandwidthSet - DescribeEIP
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type UNetClient ¶
UNetClient is the client of UNet
func NewClient ¶
func NewClient(config *ucloud.Config, credential *auth.Credential) *UNetClient
NewClient will return a instance of UNetClient
func (*UNetClient) AllocateEIP ¶
func (c *UNetClient) AllocateEIP(req *AllocateEIPRequest) (*AllocateEIPResponse, error)
AllocateEIP - 根据提供信息, 申请弹性IP
func (*UNetClient) AllocateShareBandwidth ¶
func (c *UNetClient) AllocateShareBandwidth(req *AllocateShareBandwidthRequest) (*AllocateShareBandwidthResponse, error)
AllocateShareBandwidth - 开通共享带宽
func (*UNetClient) AllocateVIP ¶
func (c *UNetClient) AllocateVIP(req *AllocateVIPRequest) (*AllocateVIPResponse, error)
AllocateVIP - 根据提供信息,申请内网VIP(Virtual IP),多用于高可用程序作为漂移IP。
func (*UNetClient) AssociateEIPWithShareBandwidth ¶
func (c *UNetClient) AssociateEIPWithShareBandwidth(req *AssociateEIPWithShareBandwidthRequest) (*AssociateEIPWithShareBandwidthResponse, error)
AssociateEIPWithShareBandwidth - 将EIP加入共享带宽
func (*UNetClient) BindEIP ¶
func (c *UNetClient) BindEIP(req *BindEIPRequest) (*BindEIPResponse, error)
BindEIP - 将尚未使用的弹性IP绑定到指定的资源
func (*UNetClient) CreateBandwidthPackage ¶
func (c *UNetClient) CreateBandwidthPackage(req *CreateBandwidthPackageRequest) (*CreateBandwidthPackageResponse, error)
CreateBandwidthPackage - 为非共享带宽模式下, 已绑定资源实例的带宽计费弹性IP附加临时带宽包
func (*UNetClient) CreateFirewall ¶
func (c *UNetClient) CreateFirewall(req *CreateFirewallRequest) (*CreateFirewallResponse, error)
CreateFirewall - 创建防火墙
func (*UNetClient) DeleteBandwidthPackage ¶
func (c *UNetClient) DeleteBandwidthPackage(req *DeleteBandwidthPackageRequest) (*DeleteBandwidthPackageResponse, error)
DeleteBandwidthPackage - 删除弹性IP上已附加带宽包
func (*UNetClient) DeleteFirewall ¶
func (c *UNetClient) DeleteFirewall(req *DeleteFirewallRequest) (*DeleteFirewallResponse, error)
DeleteFirewall - 删除防火墙
func (*UNetClient) DescribeBandwidthPackage ¶
func (c *UNetClient) DescribeBandwidthPackage(req *DescribeBandwidthPackageRequest) (*DescribeBandwidthPackageResponse, error)
DescribeBandwidthPackage - 获取某地域下的带宽包信息
func (*UNetClient) DescribeBandwidthUsage ¶
func (c *UNetClient) DescribeBandwidthUsage(req *DescribeBandwidthUsageRequest) (*DescribeBandwidthUsageResponse, error)
DescribeBandwidthUsage - 获取带宽用量信息
func (*UNetClient) DescribeEIP ¶
func (c *UNetClient) DescribeEIP(req *DescribeEIPRequest) (*DescribeEIPResponse, error)
DescribeEIP - 获取弹性IP信息
func (*UNetClient) DescribeFirewall ¶
func (c *UNetClient) DescribeFirewall(req *DescribeFirewallRequest) (*DescribeFirewallResponse, error)
DescribeFirewall - 获取防火墙组信息
func (*UNetClient) DescribeFirewallResource ¶
func (c *UNetClient) DescribeFirewallResource(req *DescribeFirewallResourceRequest) (*DescribeFirewallResourceResponse, error)
DescribeFirewallResource - 获取防火墙组所绑定资源的外网IP
func (*UNetClient) DescribeShareBandwidth ¶
func (c *UNetClient) DescribeShareBandwidth(req *DescribeShareBandwidthRequest) (*DescribeShareBandwidthResponse, error)
DescribeShareBandwidth - 获取共享带宽信息
func (*UNetClient) DescribeVIP ¶
func (c *UNetClient) DescribeVIP(req *DescribeVIPRequest) (*DescribeVIPResponse, error)
DescribeVIP - 获取内网VIP详细信息
func (*UNetClient) DisassociateEIPWithShareBandwidth ¶
func (c *UNetClient) DisassociateEIPWithShareBandwidth(req *DisassociateEIPWithShareBandwidthRequest) (*DisassociateEIPWithShareBandwidthResponse, error)
DisassociateEIPWithShareBandwidth - 将EIP移出共享带宽
func (*UNetClient) GetEIPPayMode ¶
func (c *UNetClient) GetEIPPayMode(req *GetEIPPayModeRequest) (*GetEIPPayModeResponse, error)
GetEIPPayMode - 获取弹性IP计费模式
func (*UNetClient) GetEIPPrice ¶
func (c *UNetClient) GetEIPPrice(req *GetEIPPriceRequest) (*GetEIPPriceResponse, error)
GetEIPPrice - 获取弹性IP价格
func (*UNetClient) GetEIPUpgradePrice ¶
func (c *UNetClient) GetEIPUpgradePrice(req *GetEIPUpgradePriceRequest) (*GetEIPUpgradePriceResponse, error)
GetEIPUpgradePrice - 获取弹性IP带宽改动价格
func (*UNetClient) GrantFirewall ¶
func (c *UNetClient) GrantFirewall(req *GrantFirewallRequest) (*GrantFirewallResponse, error)
GrantFirewall - 将防火墙应用到资源上
func (*UNetClient) ModifyEIPBandwidth ¶
func (c *UNetClient) ModifyEIPBandwidth(req *ModifyEIPBandwidthRequest) (*ModifyEIPBandwidthResponse, error)
ModifyEIPBandwidth - 调整弹性IP的外网带宽
func (*UNetClient) ModifyEIPWeight ¶
func (c *UNetClient) ModifyEIPWeight(req *ModifyEIPWeightRequest) (*ModifyEIPWeightResponse, error)
ModifyEIPWeight - 修改弹性IP的外网出口权重
func (*UNetClient) NewAllocateEIPRequest ¶
func (c *UNetClient) NewAllocateEIPRequest() *AllocateEIPRequest
NewAllocateEIPRequest will create request of AllocateEIP action.
func (*UNetClient) NewAllocateShareBandwidthRequest ¶
func (c *UNetClient) NewAllocateShareBandwidthRequest() *AllocateShareBandwidthRequest
NewAllocateShareBandwidthRequest will create request of AllocateShareBandwidth action.
func (*UNetClient) NewAllocateVIPRequest ¶
func (c *UNetClient) NewAllocateVIPRequest() *AllocateVIPRequest
NewAllocateVIPRequest will create request of AllocateVIP action.
func (*UNetClient) NewAssociateEIPWithShareBandwidthRequest ¶
func (c *UNetClient) NewAssociateEIPWithShareBandwidthRequest() *AssociateEIPWithShareBandwidthRequest
NewAssociateEIPWithShareBandwidthRequest will create request of AssociateEIPWithShareBandwidth action.
func (*UNetClient) NewBindEIPRequest ¶
func (c *UNetClient) NewBindEIPRequest() *BindEIPRequest
NewBindEIPRequest will create request of BindEIP action.
func (*UNetClient) NewCreateBandwidthPackageRequest ¶
func (c *UNetClient) NewCreateBandwidthPackageRequest() *CreateBandwidthPackageRequest
NewCreateBandwidthPackageRequest will create request of CreateBandwidthPackage action.
func (*UNetClient) NewCreateFirewallRequest ¶
func (c *UNetClient) NewCreateFirewallRequest() *CreateFirewallRequest
NewCreateFirewallRequest will create request of CreateFirewall action.
func (*UNetClient) NewDeleteBandwidthPackageRequest ¶
func (c *UNetClient) NewDeleteBandwidthPackageRequest() *DeleteBandwidthPackageRequest
NewDeleteBandwidthPackageRequest will create request of DeleteBandwidthPackage action.
func (*UNetClient) NewDeleteFirewallRequest ¶
func (c *UNetClient) NewDeleteFirewallRequest() *DeleteFirewallRequest
NewDeleteFirewallRequest will create request of DeleteFirewall action.
func (*UNetClient) NewDescribeBandwidthPackageRequest ¶
func (c *UNetClient) NewDescribeBandwidthPackageRequest() *DescribeBandwidthPackageRequest
NewDescribeBandwidthPackageRequest will create request of DescribeBandwidthPackage action.
func (*UNetClient) NewDescribeBandwidthUsageRequest ¶
func (c *UNetClient) NewDescribeBandwidthUsageRequest() *DescribeBandwidthUsageRequest
NewDescribeBandwidthUsageRequest will create request of DescribeBandwidthUsage action.
func (*UNetClient) NewDescribeEIPRequest ¶
func (c *UNetClient) NewDescribeEIPRequest() *DescribeEIPRequest
NewDescribeEIPRequest will create request of DescribeEIP action.
func (*UNetClient) NewDescribeFirewallRequest ¶
func (c *UNetClient) NewDescribeFirewallRequest() *DescribeFirewallRequest
NewDescribeFirewallRequest will create request of DescribeFirewall action.
func (*UNetClient) NewDescribeFirewallResourceRequest ¶
func (c *UNetClient) NewDescribeFirewallResourceRequest() *DescribeFirewallResourceRequest
NewDescribeFirewallResourceRequest will create request of DescribeFirewallResource action.
func (*UNetClient) NewDescribeShareBandwidthRequest ¶
func (c *UNetClient) NewDescribeShareBandwidthRequest() *DescribeShareBandwidthRequest
NewDescribeShareBandwidthRequest will create request of DescribeShareBandwidth action.
func (*UNetClient) NewDescribeVIPRequest ¶
func (c *UNetClient) NewDescribeVIPRequest() *DescribeVIPRequest
NewDescribeVIPRequest will create request of DescribeVIP action.
func (*UNetClient) NewDisassociateEIPWithShareBandwidthRequest ¶
func (c *UNetClient) NewDisassociateEIPWithShareBandwidthRequest() *DisassociateEIPWithShareBandwidthRequest
NewDisassociateEIPWithShareBandwidthRequest will create request of DisassociateEIPWithShareBandwidth action.
func (*UNetClient) NewGetEIPPayModeRequest ¶
func (c *UNetClient) NewGetEIPPayModeRequest() *GetEIPPayModeRequest
NewGetEIPPayModeRequest will create request of GetEIPPayMode action.
func (*UNetClient) NewGetEIPPriceRequest ¶
func (c *UNetClient) NewGetEIPPriceRequest() *GetEIPPriceRequest
NewGetEIPPriceRequest will create request of GetEIPPrice action.
func (*UNetClient) NewGetEIPUpgradePriceRequest ¶
func (c *UNetClient) NewGetEIPUpgradePriceRequest() *GetEIPUpgradePriceRequest
NewGetEIPUpgradePriceRequest will create request of GetEIPUpgradePrice action.
func (*UNetClient) NewGrantFirewallRequest ¶
func (c *UNetClient) NewGrantFirewallRequest() *GrantFirewallRequest
NewGrantFirewallRequest will create request of GrantFirewall action.
func (*UNetClient) NewModifyEIPBandwidthRequest ¶
func (c *UNetClient) NewModifyEIPBandwidthRequest() *ModifyEIPBandwidthRequest
NewModifyEIPBandwidthRequest will create request of ModifyEIPBandwidth action.
func (*UNetClient) NewModifyEIPWeightRequest ¶
func (c *UNetClient) NewModifyEIPWeightRequest() *ModifyEIPWeightRequest
NewModifyEIPWeightRequest will create request of ModifyEIPWeight action.
func (*UNetClient) NewReleaseEIPRequest ¶
func (c *UNetClient) NewReleaseEIPRequest() *ReleaseEIPRequest
NewReleaseEIPRequest will create request of ReleaseEIP action.
func (*UNetClient) NewReleaseShareBandwidthRequest ¶
func (c *UNetClient) NewReleaseShareBandwidthRequest() *ReleaseShareBandwidthRequest
NewReleaseShareBandwidthRequest will create request of ReleaseShareBandwidth action.
func (*UNetClient) NewReleaseVIPRequest ¶
func (c *UNetClient) NewReleaseVIPRequest() *ReleaseVIPRequest
NewReleaseVIPRequest will create request of ReleaseVIP action.
func (*UNetClient) NewResizeShareBandwidthRequest ¶
func (c *UNetClient) NewResizeShareBandwidthRequest() *ResizeShareBandwidthRequest
NewResizeShareBandwidthRequest will create request of ResizeShareBandwidth action.
func (*UNetClient) NewSetEIPPayModeRequest ¶
func (c *UNetClient) NewSetEIPPayModeRequest() *SetEIPPayModeRequest
NewSetEIPPayModeRequest will create request of SetEIPPayMode action.
func (*UNetClient) NewUnBindEIPRequest ¶
func (c *UNetClient) NewUnBindEIPRequest() *UnBindEIPRequest
NewUnBindEIPRequest will create request of UnBindEIP action.
func (*UNetClient) NewUpdateEIPAttributeRequest ¶
func (c *UNetClient) NewUpdateEIPAttributeRequest() *UpdateEIPAttributeRequest
NewUpdateEIPAttributeRequest will create request of UpdateEIPAttribute action.
func (*UNetClient) NewUpdateFirewallAttributeRequest ¶
func (c *UNetClient) NewUpdateFirewallAttributeRequest() *UpdateFirewallAttributeRequest
NewUpdateFirewallAttributeRequest will create request of UpdateFirewallAttribute action.
func (*UNetClient) NewUpdateFirewallRequest ¶
func (c *UNetClient) NewUpdateFirewallRequest() *UpdateFirewallRequest
NewUpdateFirewallRequest will create request of UpdateFirewall action.
func (*UNetClient) NewUpdateVIPAttributeRequest ¶
func (c *UNetClient) NewUpdateVIPAttributeRequest() *UpdateVIPAttributeRequest
NewUpdateVIPAttributeRequest will create request of UpdateVIPAttribute action.
func (*UNetClient) ReleaseEIP ¶
func (c *UNetClient) ReleaseEIP(req *ReleaseEIPRequest) (*ReleaseEIPResponse, error)
ReleaseEIP - 释放弹性IP资源, 所释放弹性IP必须为非绑定状态.
func (*UNetClient) ReleaseShareBandwidth ¶
func (c *UNetClient) ReleaseShareBandwidth(req *ReleaseShareBandwidthRequest) (*ReleaseShareBandwidthResponse, error)
ReleaseShareBandwidth - 关闭共享带宽
func (*UNetClient) ReleaseVIP ¶
func (c *UNetClient) ReleaseVIP(req *ReleaseVIPRequest) (*ReleaseVIPResponse, error)
ReleaseVIP - 释放VIP资源
func (*UNetClient) ResizeShareBandwidth ¶
func (c *UNetClient) ResizeShareBandwidth(req *ResizeShareBandwidthRequest) (*ResizeShareBandwidthResponse, error)
ResizeShareBandwidth - 调整共享带宽的带宽值
func (*UNetClient) SetEIPPayMode ¶
func (c *UNetClient) SetEIPPayMode(req *SetEIPPayModeRequest) (*SetEIPPayModeResponse, error)
SetEIPPayMode - 设置弹性IP计费模式, 切换时会涉及付费/退费.
func (*UNetClient) UnBindEIP ¶
func (c *UNetClient) UnBindEIP(req *UnBindEIPRequest) (*UnBindEIPResponse, error)
UnBindEIP - 将弹性IP从资源上解绑
func (*UNetClient) UpdateEIPAttribute ¶
func (c *UNetClient) UpdateEIPAttribute(req *UpdateEIPAttributeRequest) (*UpdateEIPAttributeResponse, error)
UpdateEIPAttribute - 更新弹性IP名称,业务组,备注等属性字段
func (*UNetClient) UpdateFirewall ¶
func (c *UNetClient) UpdateFirewall(req *UpdateFirewallRequest) (*UpdateFirewallResponse, error)
UpdateFirewall - 更新防火墙规则
func (*UNetClient) UpdateFirewallAttribute ¶
func (c *UNetClient) UpdateFirewallAttribute(req *UpdateFirewallAttributeRequest) (*UpdateFirewallAttributeResponse, error)
UpdateFirewallAttribute - 更新防火墙规则
func (*UNetClient) UpdateVIPAttribute ¶
func (c *UNetClient) UpdateVIPAttribute(req *UpdateVIPAttributeRequest) (*UpdateVIPAttributeResponse, error)
UpdateVIPAttribute - 更新VIP信息
type UnBindEIPRequest ¶
type UnBindEIPRequest struct {
request.CommonBase
// 弹性IP的资源Id
EIPId *string `required:"true"`
// 弹性IP请求解绑的资源类型, 枚举值为: uhost: 云主机; ulb, 负载均衡器 upm: 物理机; hadoophost: 大数据集群;fortresshost:堡垒机;udockhost:容器;udhost:私有专区主机;natgw:NAT网关;udb:udb;vpngw:ipsec vpn;ucdr:云灾备;dbaudit:数据库审计;
ResourceType *string `required:"true"`
// 弹性IP请求解绑的资源ID
ResourceId *string `required:"true"`
}
UnBindEIPRequest is request schema for UnBindEIP action
type UnBindEIPResponse ¶
type UnBindEIPResponse struct {
response.CommonBase
}
UnBindEIPResponse is response schema for UnBindEIP action
type UnetAllocateEIPSet ¶
type UnetAllocateEIPSet struct {
// 申请到的EIP资源ID
EIPId string
// 申请到的IPv4地址.
EIPAddr []UnetEIPAddrSet
}
UnetAllocateEIPSet - AllocateEIP
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type UnetBandwidthPackageSet ¶
type UnetBandwidthPackageSet struct {
// 带宽包的资源ID
BandwidthPackageId string
// 生效时间, 格式为 Unix Timestamp
EnableTime int
// 失效时间, 格式为 Unix Timestamp
DisableTime int
// 创建时间, 格式为 Unix Timestamp
CreateTime int
// 带宽包的临时带宽值, 单位Mbps
Bandwidth int
// 带宽包所绑定弹性IP的资源ID
EIPId string
// 带宽包所绑定弹性IP的详细信息,只有当EIPId对应双线IP时, EIPAddr的长度为2, 其他情况, EIPAddr长度均为1.参见 EIPAddrSet
EIPAddr []EIPAddrSet
}
UnetBandwidthPackageSet - DescribeBandwidthPackage
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type UnetBandwidthUsageEIPSet ¶
type UnetBandwidthUsageEIPSet struct {
// 最近5分钟带宽用量, 单位Mbps
CurBandwidth float64
// 弹性IP资源ID
EIPId string
}
UnetBandwidthUsageEIPSet - DescribeBandwidthUsage
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type UnetEIPAddrSet ¶
type UnetEIPAddrSet struct {
// 运营商信息如: 国际: International, BGP: BGP
OperatorName string
// IP地址
IP string
}
UnetEIPAddrSet - AllocateEIP
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type UnetEIPResourceSet ¶
type UnetEIPResourceSet struct {
// 已绑定的资源类型, 枚举值为: uhost, 云主机;natgw:NAT网关;ulb:负载均衡器;upm: 物理机; hadoophost: 大数据集群;fortresshost:堡垒机;udockhost:容器;udhost:私有专区主机;vpngw:IPSec VPN;ucdr:云灾备;dbaudit:数据库审计。
ResourceType string
// 已绑定的资源名称
ResourceName string
// 已绑定资源的资源ID
ResourceId string
// 弹性IP的资源ID
EIPId string
}
UnetEIPResourceSet - DescribeEIP
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type UnetEIPSet ¶
type UnetEIPSet struct {
// 弹性IP的资源ID
EIPId string
// 外网出口权重, 默认为50, 范围[0-100]
Weight int
// 带宽模式, 枚举值为: 0: 非共享带宽模式, 1: 共享带宽模式
BandwidthType int
// 弹性IP的带宽, 单位为Mbps, 当BandwidthType=1时, 该处显示为共享带宽值. 当BandwidthType=0时, 该处显示这个弹性IP的带宽.
Bandwidth int
// 弹性IP的资源绑定状态, 枚举值为: used: 已绑定, free: 未绑定, freeze: 已冻结
Status string
// 付费方式, 枚举值为: Year, 按年付费; Month, 按月付费; Dynamic, 按小时付费; Trial, 试用. 按小时付费和试用这两种付费模式需要开通权限.
ChargeType string
// 弹性IP的创建时间, 格式为Unix Timestamp
CreateTime int
// 弹性IP的到期时间, 格式为Unix Timestamp
ExpireTime int
// 弹性IP的详细信息列表, 具体结构见下方 UnetEIPResourceSet
Resource UnetEIPResourceSet
// 弹性IP的详细信息列表, 具体结构见下方 UnetEIPAddrSet
EIPAddr []UnetEIPAddrSet
// 弹性IP的名称,缺省值为 "EIP"
Name string
// 弹性IP的业务组标识, 缺省值为 "Default"
Tag string
// 弹性IP的备注, 缺省值为 ""
Remark string
// 弹性IP的计费模式, 枚举值为: "Bandwidth", 带宽计费; "Traffic", 流量计费; "ShareBandwidth",共享带宽模式. 默认为 "Bandwidth".
PayMode string
ShareBandwidthSet ShareBandwidthSet
// 弹性IP是否到期
Expire bool
}
UnetEIPSet - DescribeEIP
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type UnetShareBandwidthSet ¶
type UnetShareBandwidthSet struct {
ShareBandwidth int
ShareBandwidthId string
ChargeType string
CreateTime int
ExpireTime int
EIPSet []EIPSetData
BandwidthGuarantee int
PostPayStartTime int
Name string
}
UnetShareBandwidthSet - DescribeShareBandwidth
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn for detail.
type UpdateEIPAttributeRequest ¶
type UpdateEIPAttributeRequest struct {
request.CommonBase
// EIP资源ID
EIPId *string `required:"true"`
// 名字(Name Tag Remark都为空则报错)
Name *string `required:"false"`
// 业务
Tag *string `required:"false"`
// 备注
Remark *string `required:"false"`
}
UpdateEIPAttributeRequest is request schema for UpdateEIPAttribute action
type UpdateEIPAttributeResponse ¶
type UpdateEIPAttributeResponse struct {
response.CommonBase
}
UpdateEIPAttributeResponse is response schema for UpdateEIPAttribute action
type UpdateFirewallAttributeRequest ¶
type UpdateFirewallAttributeRequest struct {
request.CommonBase
// 防火墙资源ID
FWId *string `required:"true"`
// 防火墙名称,默认为空,为空则不做修改。Name,Tag,Remark必须填写1个及以上
Name *string `required:"false"`
// 防火墙业务组,默认为空,为空则不做修改。Name,Tag,Remark必须填写1个及以上
Tag *string `required:"false"`
// 防火墙备注,默认为空,为空则不做修改。Name,Tag,Remark必须填写1个及以上
Remark *string `required:"false"`
}
UpdateFirewallAttributeRequest is request schema for UpdateFirewallAttribute action
type UpdateFirewallAttributeResponse ¶
type UpdateFirewallAttributeResponse struct {
response.CommonBase
}
UpdateFirewallAttributeResponse is response schema for UpdateFirewallAttribute action
type UpdateFirewallRequest ¶
type UpdateFirewallRequest struct {
request.CommonBase
// 防火墙资源ID
FWId *string `required:"true"`
// 防火墙规则,例如:TCP|22|192.168.1.1/22|DROP|LOW|禁用22端口,第一个参数代表协议:第二个参数代表端口号,第三个参数为ip,第四个参数为ACCEPT(接受)和DROP(拒绝),第五个参数优先级:HIGH(高),MEDIUM(中),LOW(低),第六个参数为该条规则的自定义备注
Rule []string `required:"true"`
}
UpdateFirewallRequest is request schema for UpdateFirewall action
type UpdateFirewallResponse ¶
type UpdateFirewallResponse struct {
response.CommonBase
// 防火墙id
FWId string
}
UpdateFirewallResponse is response schema for UpdateFirewall action
type UpdateVIPAttributeRequest ¶
type UpdateVIPAttributeRequest struct {
request.CommonBase
// 内网VIP的名称
Name *string `required:"false"`
// 内网VIP的备注
Remark *string `required:"false"`
// 内网VIP所属的业务组
Tag *string `required:"false"`
// 内网VIP的资源Id
VIPId *string `required:"true"`
}
UpdateVIPAttributeRequest is request schema for UpdateVIPAttribute action
type UpdateVIPAttributeResponse ¶
type UpdateVIPAttributeResponse struct {
response.CommonBase
}
UpdateVIPAttributeResponse is response schema for UpdateVIPAttribute action
type VIPDetailSet ¶
type VIPDetailSet struct {
// 创建时间
CreateTime int
// VIP名称
Name string
// 真实主机ip
RealIp string
// VIP备注
Remark string
// 子网id
SubnetId string
// VIP所属业务组
Tag string
// 虚拟ip
VIP string
// 虚拟ip id
VIPId string
// VPC id
VPCId string
// 地域
Zone string
}
VIPDetailSet - VIPDetailSet
this model is auto created by ucloud code generater for open api, you can also see https://docs.ucloud.cn/api for detail.
Source Files
¶
- allocate_eip.go
- allocate_share_bandwidth.go
- allocate_vip.go
- associate_eipwith_share_bandwidth.go
- bind_eip.go
- client.go
- create_bandwidth_package.go
- create_firewall.go
- delete_bandwidth_package.go
- delete_firewall.go
- describe_bandwidth_package.go
- describe_bandwidth_usage.go
- describe_eip.go
- describe_firewall.go
- describe_firewall_resource.go
- describe_share_bandwidth.go
- describe_vip.go
- disassociate_eipwith_share_bandwidth.go
- doc.go
- get_eippay_mode.go
- get_eipprice.go
- get_eipupgrade_price.go
- grant_firewall.go
- modify_eipbandwidth.go
- modify_eipweight.go
- release_eip.go
- release_share_bandwidth.go
- release_vip.go
- resize_share_bandwidth.go
- set_eippay_mode.go
- types_eipaddr_set.go
- types_eippay_mode_set.go
- types_eipprice_detail_set.go
- types_eipset_data.go
- types_firewall_data_set.go
- types_firewall_rule_set.go
- types_resource_set.go
- types_share_bandwidth_set.go
- types_unet_allocate_eipset.go
- types_unet_bandwidth_package_set.go
- types_unet_bandwidth_usage_eipset.go
- types_unet_eipaddr_set.go
- types_unet_eipresource_set.go
- types_unet_eipset.go
- types_unet_share_bandwidth_set.go
- types_vip_detail_set.go
- types_vipset.go
- un_bind_eip.go
- update_eipattribute.go
- update_firewall.go
- update_firewall_attribute.go
- update_vip_attribute.go