Documentation
¶
Overview ¶
Package waiter is a helper package use for waiting remote state is transformed into target state.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RefreshFunc ¶
RefreshFunc is the function to query remote resource state
type StateWaiter ¶
type StateWaiter struct {
Pending []string
Target []string
Refresh RefreshFunc
Delay time.Duration
Timeout time.Duration
MinTimeout time.Duration
PollInterval time.Duration
}
StateWaiter is the waiter that waiting for remote state achieve to target state
func (*StateWaiter) Wait ¶
func (waiter *StateWaiter) Wait() (interface{}, error)
Wait watches an object and waits for it to achieve the state
Click to show internal directories.
Click to hide internal directories.